@@ -49,7 +49,7 @@ KDirSaver::cd( const TQString & newPath )
 {
     if ( ! newPath.isEmpty() )
     {
-	chdir( newPath );
+	chdir( newPath.local8Bit() );
     }
 }
 
@@ -64,7 +64,7 @@ KDirSaver::currentDirPath() const
 void
 KDirSaver::restore()
 {
-    chdir( oldWorkingDir.path() );
+    chdir( oldWorkingDir.path().local8Bit() );
 }
 
 
