@@ -12,7 +12,7 @@
 #include <string.h>
 #include <sys/errno.h>
 #include <tqtimer.h>
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdelocale.h>
 #include <tdeconfig.h>
 #include "kdirtree.h"
