@@ -13,7 +13,7 @@
 #include <tqevent.h>
 #include <tqregexp.h>
 
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdeconfig.h>
 #include <tdeglobal.h>
 #include <tdelocale.h>
