@@ -43,7 +43,7 @@ namespace KDirStat
 
     class KTreemapView:	public TQCanvasView
     {
-	Q_OBJECT
+	TQ_OBJECT
   
 
     public:
